@@ -431,7 +431,7 @@ parse_settings (guchar      *data,
         memcpy (setting->name, buffer.pos, name_len);
 
         setting->name[name_len] = '\0';
-        setting->channel_name = g_ascii_strup (channel_name, -1);
+        setting->channel_name = g_ascii_strup (channel_name, strlen (channel_name));
         buffer.pos += pad_len;
 
         result = fetch_card32 (&buffer, &v_int);
